/// <reference types="node" />
declare type Env = 'development' | 'staging' | 'production';
interface User {
    email: string;
}
interface JSONObject {
    [x: string]: JSONValue;
}
declare type JSONValue = string | number | boolean | {
    [x: string]: JSONValue;
} | Array<JSONValue>;
interface MainData {
    features: {
        [key in string]: boolean;
    };
    configs: {
        [key in string]: JSONObject;
    };
}
interface Constructor {
    publicApiKey: string;
    env: Env;
}
declare class FeatureFlags {
    _apiKey: string;
    _env: Env;
    _user?: User;
    _intervalId?: NodeJS.Timer;
    _features: {
        [key in string]: boolean;
    };
    _configs: {
        [key in string]: JSONObject;
    };
    constructor({ publicApiKey, env }: Constructor);
    fetchFeatureFlags(user: User): Promise<void>;
    isOn(featureName: string): boolean;
    getConfig(featureName: string): JSONObject;
    _fetchFlags(): Promise<void>;
    _reportFeatureShown(featureName: string): Promise<void>;
    _saveToLocalStorage(data: MainData): void;
    _getFromLocalStorage(): any;
}
declare const _default: {
    create: ({ publicApiKey, env }: Constructor) => FeatureFlags;
};
export default _default;
